#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 panic
version:              0.4.0.1
visibility:           public
id:                   panic-0.4.0.1-LjSerD2Hu1fK37HhFAQEbK
key:                  panic-0.4.0.1-LjSerD2Hu1fK37HhFAQEbK
license:              ISC
maintainer:           iavor.diatchki@gmail.com
author:               Iavor Diatchki
synopsis:             A convenient way to panic.
description:          A convenient way to panic.
category:             Development
abi:                  bacadb6c37f4edc012d06418910b81e9
exposed:              True
exposed-modules:      Panic
import-dirs:          /usr/lib/ghc-9.6.6/site-local/panic-0.4.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/panic-0.4.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/panic-0.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-panic
hs-libraries:         HSpanic-0.4.0.1-LjSerD2Hu1fK37HhFAQEbK
depends:
    base-4.18.2.1 gitrev-1.3.1-HjgHeGOzFY1JvYhlt8eDSs
    template-haskell-2.20.0.0

haddock-interfaces:   /usr/share/doc/haskell-panic/html/panic.haddock
haddock-html:         /usr/share/doc/haskell-panic/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

